# PyLaysWebhooker
A discord webhook program i made based off my webhooker site https://layswebhooker.vercel.app
You're gonna need requests module to install this module.
```
pip install requests
```
Basically i made this for discord webhook message sending to be easier for others, like Discohook.
Here is an example of a code to send a webhook message in the console
```
import pyLaysWebhooker
pyLaysWebhooker.pySend()
```